@@ -2,5 +2,6 @@
 
 from .client import SimpleRegistryClient
 from .integration import RegistryIntegration
+from .operations import MCPServerOperations
 
-__all__ = ["SimpleRegistryClient", "RegistryIntegration"]
+__all__ = ["SimpleRegistryClient", "RegistryIntegration", "MCPServerOperations"]
