@@ -3,7 +3,8 @@
 from .base import RuntimeAdapter
 from .llm_runtime import LLMRuntime
 from .codex_runtime import CodexRuntime
+from .copilot_runtime import CopilotRuntime
 from .factory import RuntimeFactory
 from .manager import RuntimeManager
 
-__all__ = ["RuntimeAdapter", "LLMRuntime", "CodexRuntime", "RuntimeFactory", "RuntimeManager"]
+__all__ = ["RuntimeAdapter", "LLMRuntime", "CodexRuntime", "CopilotRuntime", "RuntimeFactory", "RuntimeManager"]
